<?php

namespace app\admin\controller\user;

use app\common\controller\Backend;
use think\Db;

/**
 * 
 *
 * @icon fa fa-circle-o
 */
class Agent extends Backend
{
    
    /**
     * Agent模型对象
     * @var \app\admin\model\user\Agent
     */
    protected $model = null;

    public function _initialize()
    {
        parent::_initialize();
        $this->model = new \app\admin\model\user\Agent;
        $this->view->assign("typeList", $this->model->getTypeList());
        $this->view->assign("statusList", $this->model->getStatusList());
    }

    /**
     * 查看
     */
    public function index()
    {
        //设置过滤方法
        $this->request->filter(['strip_tags']);
        if ($this->request->isAjax()) {
            //如果发送的来源是Selectpage，则转发到Selectpage
            if ($this->request->request('keyField')) {
                return $this->selectpage();
            }
            list($where, $sort, $order, $offset, $limit) = $this->buildparams();
            $total = $this->model
                ->where($where)
                ->order($sort, $order)
                ->count();
            $list = $this->model
                ->with("users,agent,family")
                ->where($where)
                ->order($sort, $order)
                ->limit($offset, $limit)
                ->select();
            $list = collection($list)->toArray();
            foreach ($list as $key => $val) {
                if($val['area_id']){
                    $area = Db::name('addr')->where(['ID' => $val['area_id']])->find();
                    $list[$key]['MergerName'] = $area['MergerName'];
                }else if($val['city_id']){
                    $city = Db::name('addr')->where(['ID' => $val['city_id']])->find();
                    $list[$key]['MergerName'] = $city['MergerName'];
                }else if($val['province_id']){
                    $province = Db::name('addr')->where(['ID' => $val['province_id']])->find();
                    $list[$key]['MergerName'] = $province['MergerName'];
                }
            }
            $result = array("total" => $total, "rows" => $list);
            return json($result);
        }
        return $this->view->fetch();
    }

    /**
     * 添加
     */
    public function add()
    {
        if ($this->request->isPost()) {
            $params = $this->request->post("row/a");
            if ($params) {
                $params = $this->preExcludeFields($params);

                if ($this->dataLimit && $this->dataLimitFieldAutoFill) {
                    $params[$this->dataLimitField] = $this->auth->id;
                }
                $result = false;
                Db::startTrans();
                try {
                    //是否采用模型验证
                    if ($this->modelValidate) {
                        $name = str_replace("\\model\\", "\\validate\\", get_class($this->model));
                        $validate = is_bool($this->modelValidate) ? ($this->modelSceneValidate ? $name . '.add' : $name) : $this->modelValidate;
                        $this->model->validateFailException(true)->validate($validate);
                    }

                    if(in_array($params["type"],[1,2]) ){
                        if(empty($params['family_id'])){
                            $this->error("请选择族谱ID");
                        }
                        unset($params['province_id']);unset($params['city_id']);unset($params['area_id']);
                    }else{
                        if($params["type"] == 3){
                            if(empty($params['province_id'])){
                                $this->error("请选择省级");
                            }
                            unset($params['city_id']);unset($params['area_id']);
                        }else if($params["type"] == 4){
                            if(empty($params['city_id'])){
                                $this->error("请选择市级");
                            }
                            unset($params['area_id']);
                        }else if($params["type"] == 5){
                            if(empty($params['area_id'])){
                                $this->error("请选择区县级");
                            }
                        }
                        unset($params['family_id']);
                    }

                    $result = $this->model->allowField(true)->save($params);
                    Db::commit();
                } catch (ValidateException $e) {
                    Db::rollback();
                    $this->error($e->getMessage());
                } catch (PDOException $e) {
                    Db::rollback();
                    $this->error($e->getMessage());
                } catch (Exception $e) {
                    Db::rollback();
                    $this->error($e->getMessage());
                }
                if ($result !== false) {
                    $this->success();
                } else {
                    $this->error(__('No rows were inserted'));
                }
            }
            $this->error(__('Parameter %s can not be empty', ''));
        }
        return $this->view->fetch();
    }

    /**
     * 编辑
     */
    public function edit($ids = null)
    {
        $row = $this->model->get($ids);
        if (!$row) {
            $this->error(__('No Results were found'));
        }
        $adminIds = $this->getDataLimitAdminIds();
        if (is_array($adminIds)) {
            if (!in_array($row[$this->dataLimitField], $adminIds)) {
                $this->error(__('You have no permission'));
            }
        }
        if ($this->request->isPost()) {
            $params = $this->request->post("row/a");
            if ($params) {
                $params = $this->preExcludeFields($params);
                $result = false;
                Db::startTrans();
                try {
                    //是否采用模型验证
                    if ($this->modelValidate) {
                        $name = str_replace("\\model\\", "\\validate\\", get_class($this->model));
                        $validate = is_bool($this->modelValidate) ? ($this->modelSceneValidate ? $name . '.edit' : $name) : $this->modelValidate;
                        $row->validateFailException(true)->validate($validate);
                    }

                    if(in_array($params["type"],[1,2]) ){
                        if(empty($params['family_id'])){
                            $this->error("请选择族谱ID");
                        }
                        unset($params['province_id']);unset($params['city_id']);unset($params['area_id']);
                    }else{
                        if($params["type"] == 3){
                            if(empty($params['province_id'])){
                                $this->error("请选择省级");
                            }
                            unset($params['city_id']);unset($params['area_id']);
                        }else if($params["type"] == 4){
                            if(empty($params['city_id'])){
                                $this->error("请选择市级");
                            }
                            unset($params['area_id']);
                        }else if($params["type"] == 5){
                            if(empty($params['area_id'])){
                                $this->error("请选择区县级");
                            }
                        }
                        unset($params['family_id']);
                    }

                    $result = $row->allowField(true)->save($params);
                    Db::commit();
                } catch (ValidateException $e) {
                    Db::rollback();
                    $this->error($e->getMessage());
                } catch (PDOException $e) {
                    Db::rollback();
                    $this->error($e->getMessage());
                } catch (Exception $e) {
                    Db::rollback();
                    $this->error($e->getMessage());
                }
                if ($result !== false) {
                    $this->success();
                } else {
                    $this->error(__('No rows were updated'));
                }
            }
            $this->error(__('Parameter %s can not be empty', ''));
        }
        $this->view->assign("row", $row);
        return $this->view->fetch();
    }
    

}
